@@ -27,17 +27,15 @@ except ImportError:
 
 from PyQt4.QtGui import (QIcon, QPixmap, QHBoxLayout, QGridLayout, QColorDialog,
                          QPushButton, QLineEdit, QCheckBox, QComboBox, QWidget,
-                         QTabWidget, QFileDialog, QGroupBox, QLabel, QTextEdit,
-                         QFrame, QDateEdit, QDateTimeEdit)
+                         QTabWidget, QGroupBox, QLabel, QTextEdit, QFrame,
+                         QDateEdit, QDateTimeEdit)
 from PyQt4.QtCore import Qt, QObject, QStringList, SIGNAL
 
 from guidata.utils import update_dataset, restore_dataset, utf8_to_unicode
-from guidata.qthelpers import text_to_qcolor, get_std_icon
+from guidata.qthelpers import text_to_qcolor, get_std_icon, getExistingDirectory
 from guidata.configtools import get_icon, get_image_layout, get_image_file_path
 from guidata.config import _
 
-from guidata.qtarrayeditor import ArrayEditor
-
 # ========================== <!> IMPORTANT <!> =================================
 #
 # In this module, `item` is an instance of DataItemVariable (not DataItem)
@@ -222,30 +220,40 @@ class LineEditWidget(AbstractDataSetWidget):
                 self.edit.setEnabled(False)
             self.edit.setToolTip(_("Value is forced to %d") % item.get_max())
         QObject.connect(self.edit, SIGNAL("textChanged(QString)"),
-                        self.line_edit_changed )
+                        self.line_edit_changed)
 
     def get(self):
         """Override AbstractDataSetWidget method"""
         value = self.item.get()
+        old_value = unicode(self.value())
         if value is not None:
-            self.edit.setText(utf8_to_unicode(value))
-        self.line_edit_changed( value )
+            uvalue = utf8_to_unicode(value)
+            if uvalue!=old_value:
+                self.edit.setText(utf8_to_unicode(value))
+                self.line_edit_changed(value)
+        else:
+            self.line_edit_changed(value)
             
     def line_edit_changed(self, qvalue):
         """QLineEdit validator"""
         value = self.item.from_string(unicode(qvalue))
         if not self.item.check_value(value):
-            self.edit.setStyleSheet( "background-color:rgb(255, 175, 90);" )
+            self.edit.setStyleSheet("background-color:rgb(255, 175, 90);")
         else:
-            self.edit.setStyleSheet( "" )
+            self.edit.setStyleSheet("")
+            cb = self.item.get_prop_value("display", "callback", None)
+            if cb is not None:
+                cb(self.item.instance, self.item.item, value)
         self.update(value)
         
     def update(self, value):
         """Override AbstractDataSetWidget method"""
-        pass
+        cb = self.item.get_prop_value("display", "value_callback", None)
+        if cb is not None:
+            cb(value)
 
     def value(self):
-        return self.edit.text()
+        return unicode(self.edit.text())
 
     def check(self):
         """Override AbstractDataSetWidget method"""
@@ -282,9 +290,9 @@ class TextEditWidget(AbstractDataSetWidget):
         """QLineEdit validator"""
         value = self.item.from_string(self.__get_text())
         if not self.item.check_value(value):
-            self.edit.setStyleSheet( "background-color:rgb(255, 175, 90);" )
+            self.edit.setStyleSheet("background-color:rgb(255, 175, 90);")
         else:
-            self.edit.setStyleSheet( "" )
+            self.edit.setStyleSheet("")
         self.update(value)
         
     def update(self, value):
@@ -428,7 +436,8 @@ class ColorWidget(HLayoutMixin, LineEditWidget):
         self.group.addWidget(self.button)
         
     def update(self, value):
-        """Override AbstractDataSetWidget method"""
+        """Reimplement LineEditWidget method"""
+        LineEditWidget.update(self, value)
         color = text_to_qcolor(value)
         if color.isValid():
             bitmap = QPixmap(16, 16)
@@ -463,6 +472,7 @@ class FileWidget(HLayoutMixin, LineEditWidget):
         QObject.connect(button, SIGNAL("clicked()"), self.select_file)
         self.group.addWidget(button)
         self.basedir = item.get_prop_value("data", "basedir")
+        self.all_files_first = item.get_prop_value("data", "all_files_first")
 
     def select_file(self):
         """Open a file selection dialog box"""
@@ -478,9 +488,12 @@ class FileWidget(HLayoutMixin, LineEditWidget):
         formats = [unicode(format).lower() for format in _formats]
         filter_lines = [(_("%s files")+" (*.%s)") % (format.upper(), format)
                         for format in formats]
+        all_filter = _("All supported files")+" (*.%s)" % " *.".join(formats)
         if len(formats) > 1:
-            filter_lines.append(_("All supported files")+" (*.%s)" \
-                                % " *.".join(formats))
+            if self.all_files_first:
+                filter_lines.insert(0, all_filter)
+            else:
+                filter_lines.append(all_filter)
         if fname is None:
             fname = ""
         try:
@@ -511,16 +524,13 @@ class DirectoryWidget(HLayoutMixin, LineEditWidget):
         """Open a directory selection dialog box"""
         value = self.item.from_string(unicode(self.edit.text()))
         parent = self.parent_layout.parent
-        _temp = sys.stdout
-        sys.stdout = None
-        if isinstance(parent, QGroupBox):
-            child_title = parent.parent().child_title
-        else:
+        try:
             child_title = parent.child_title
-        dname = QFileDialog.getExistingDirectory(parent,
-                                                 child_title(self.item),
-                                                 os.path.basename(value))
-        sys.stdout = _temp
+        except AttributeError:
+            child_title = parent.parent().child_title
+        dname = getExistingDirectory(parent,
+                                     child_title(self.item),
+                                     os.path.basename(value))
         if dname:
             self.edit.setText(dname)
 
@@ -639,7 +649,7 @@ class FloatArrayWidget(AbstractDataSetWidget):
         
         self.first_line, self.dim_label = get_image_layout("shape.png",
                                    _("Number of rows x Number of columns"))
-        edit_button = QPushButton(get_icon("table.png"),"")
+        edit_button = QPushButton(get_icon("arredit.png"),"")
         edit_button.setToolTip(_("Edit array contents"))
         edit_button.setMaximumWidth(32)
         self.first_line.addWidget(edit_button)
@@ -659,9 +669,9 @@ class FloatArrayWidget(AbstractDataSetWidget):
     def edit_array(self):
         """Open an array editor dialog"""
         label = self.item.get_prop_value("display", "label")
-        format = self.item.get_prop_value("display", "format")
+        from guidata.editors.arrayeditor import ArrayEditor
         editor = ArrayEditor(self.parent_layout.parent)
-        if editor.setup_and_check(self.arr, title=label, format=format):
+        if editor.setup_and_check(self.arr, title=label):
             if editor.exec_():
                 self.update(self.arr)
         
@@ -752,10 +762,13 @@ class ButtonWidget(AbstractDataSetWidget):
         layout.addWidget(self.group, row, label_column, row_span, column_span+1)
 
     def clicked(self, *args):
+        callback = self.item.get_prop_value("display", "callback")
         inst = self.item.instance
         item = self.item.item
-        callback = self.item.get_prop_value("display", "callback")
-        self.cb_value = callback( inst, item, self.cb_value )
+        value = self.cb_value
+        parent = self.button.parent()
+        self.cb_value = callback(inst, item, value, parent)
+        self.set()
         for widget in self.parent_layout.widgets:
             # instance may have been modified so we update all the
             # widgets of the instance
