@@ -54,7 +54,9 @@ class DataSetEditDialog(QDialog):
         self.apply_func = apply
         self.layout = QVBoxLayout()
         if instance.get_comment():
-            self.layout.addWidget(QLabel(instance.get_comment()))
+            label = QLabel(instance.get_comment())
+            label.setWordWrap(True)
+            self.layout.addWidget(label)
         self.instance = instance
         self.edit_layout = [  ]
 
@@ -146,7 +148,9 @@ class DataSetGroupEditDialog(DataSetEditDialog):
             layout = QVBoxLayout()
             layout.setAlignment(Qt.AlignTop)
             if dataset.get_comment():
-                layout.addWidget(QLabel(dataset.get_comment()))
+                label = QLabel(dataset.get_comment())
+                label.setWordWrap(True)
+                layout.addWidget(label)
             grid = QGridLayout()
             self.edit_layout.append( self.layout_factory(dataset, grid) )
             layout.addLayout(grid)
@@ -288,7 +292,7 @@ class DataSetEditLayout(object):
 from guidata.dataset.dataitems import (FloatItem, StringItem, TextItem, IntItem,
                 BoolItem, ColorItem, FileOpenItem, FilesOpenItem, FileSaveItem,
                 DirectoryItem, ChoiceItem, ImageChoiceItem, MultipleChoiceItem,
-                FloatArrayItem, ButtonItem, DateItem, DateTimeItem)
+                FloatArrayItem, ButtonItem, DateItem, DateTimeItem, DictItem)
 
 DataSetEditLayout.register(GroupItem, GroupWidget)
 DataSetEditLayout.register(TabGroupItem, TabGroupWidget)
@@ -312,6 +316,7 @@ DataSetEditLayout.register(ImageChoiceItem, ChoiceWidget)
 DataSetEditLayout.register(MultipleChoiceItem, MultipleChoiceWidget)
 DataSetEditLayout.register(FloatArrayItem, FloatArrayWidget)
 DataSetEditLayout.register(ButtonItem, ButtonWidget)
+DataSetEditLayout.register(DictItem, ButtonWidget)
 
 
 LABEL_CSS = """
@@ -350,10 +355,14 @@ class DataSetShowWidget(AbstractDataSetWidget):
             return repval
         else:
             fmt = self.item.get_prop_value("display", "format", u"%s")
-            if isinstance(fmt, basestring):
+            func = self.item.get_prop_value("display", "func", lambda x:x)
+            if callable(fmt) and value is not None:
+                return fmt(func(value))
+            elif isinstance(fmt, basestring):
                 fmt = unicode(fmt)
+
             if value is not None:
-                text = fmt % (value,)
+                text = fmt % (func(value), )
             else:
                 text = u""
             return text
@@ -435,17 +444,23 @@ DataSetShowLayout.register(FloatArrayItem, ShowFloatArrayWidget)
 
 class DataSetShowGroupBox(QGroupBox):
     """Group box widget showing a read-only DataSet"""
-    def __init__(self, label, klass):
+    def __init__(self, label, klass, **kwargs):
         QGroupBox.__init__(self, label)
         self.klass = klass
-        self.dataset = klass()
-        self.layout = QGridLayout()
+        self.dataset = klass(**kwargs)
+        self.layout = QVBoxLayout()
+        if self.dataset.get_comment():
+            label = QLabel(self.dataset.get_comment())
+            label.setWordWrap(True)
+            self.layout.addWidget(label)
+        self.grid_layout = QGridLayout()
+        self.layout.addLayout(self.grid_layout)
         self.setLayout(self.layout)
         self.edit = self.get_edit_layout()
         
     def get_edit_layout(self):
         """Return edit layout"""
-        return DataSetShowLayout(self, self.dataset, self.layout) 
+        return DataSetShowLayout(self, self.dataset, self.grid_layout) 
 
     def get(self):
         """Update group box contents from data item values"""
@@ -462,22 +477,25 @@ class DataSetEditGroupBox(DataSetShowGroupBox):
     button_text: action button text (default: "Apply")
     button_icon: QIcon object or string (default "apply.png")
     """
-    def __init__(self, label, klass, button_text=None, button_icon=None):
-        DataSetShowGroupBox.__init__(self, label, klass)
-        if button_text is None:
-            button_text = _("Apply")
-        if button_icon is None:
-            button_icon = get_icon("apply.png")
-        elif isinstance(button_icon, basestring):
-            button_icon = get_icon(button_icon)
-        apply_btn = QPushButton(button_icon, button_text, self)
-        self.connect(apply_btn, SIGNAL("clicked()"), self.set)
-        layout = self.edit.layout
-        layout.addWidget(apply_btn, layout.rowCount(), 0, 1, -1, Qt.AlignRight)
-        
+    def __init__(self, label, klass, button_text=None, button_icon=None,
+                 show_button=True, **kwargs):
+        DataSetShowGroupBox.__init__(self, label, klass, **kwargs)
+        if show_button:
+            if button_text is None:
+                button_text = _("Apply")
+            if button_icon is None:
+                button_icon = get_icon("apply.png")
+            elif isinstance(button_icon, basestring):
+                button_icon = get_icon(button_icon)
+            apply_btn = QPushButton(button_icon, button_text, self)
+            self.connect(apply_btn, SIGNAL("clicked()"), self.set)
+            layout = self.edit.layout
+            layout.addWidget(apply_btn, layout.rowCount(),
+                             0, 1, -1, Qt.AlignRight)
+
     def get_edit_layout(self):
         """Return edit layout"""
-        return DataSetEditLayout(self, self.dataset, self.layout)
+        return DataSetEditLayout(self, self.dataset, self.grid_layout)
         
     def set(self):
         """Update data item values from layout contents"""
